@@ -24,7 +24,7 @@
 #' @importFrom stats setNames
 flextable <- function( data, col_keys = names(data), cwidth = .75, cheight = .25 ){
 
-  stopifnot(is.data.frame(data))
+  stopifnot(is.data.frame(data), ncol(data) > 0 )
   if( any( duplicated(col_keys) ) ){
     stop("duplicated col_keys")
   }
