@@ -77,17 +77,20 @@ cell_fun <- list(
 
 # row_fun ----
 row_fun <- list(
-  wml = function(rowheights, str, header){
-    paste0( "<w:tr><w:trPr><w:cantSplit/><w:trHeight w:val=",
+  wml = function(rowheights, str, header, split = FALSE){
+
+    paste0( "<w:tr><w:trPr>",
+            ifelse(split, "", "<w:cantSplit/>"),
+            "<w:trHeight w:val=",
             shQuote( round(rowheights * 72*20, 0 ), type = "cmd"), "/>",
             ifelse( header, "<w:tblHeader/>", ""),
             "</w:trPr>", str, "</w:tr>")
   },
-  pml = function(rowheights, str, header){
+  pml = function(rowheights, str, header, ...){
     paste0( "<a:tr h=\"", round(rowheights * 914400, 0 ), "\">",
             str, "</a:tr>")
   },
-  html = function(rowheights, str, header) {
+  html = function(rowheights, str, header, ...) {
     str <- str_replace_all(str, pattern = "<td style=\"",
                     replacement = paste0("<td style=\"height:",
                                          round(72*rowheights), "px;"))
@@ -98,7 +101,8 @@ row_fun <- list(
 
 # main functions ----
 #' @importFrom gdtools raster_write raster_str
-format.complex_tabpart <- function( x, type = "wml", header = FALSE, ... ){
+format.complex_tabpart <- function( x, type = "wml", header = FALSE,
+                                    split = FALSE, ... ){
   stopifnot(length(type) == 1)
   stopifnot( type %in% c("wml", "pml", "html") )
 
@@ -129,18 +133,17 @@ format.complex_tabpart <- function( x, type = "wml", header = FALSE, ... ){
     pr_id = names(text_fp),
     format = as.character( sapply(text_fp, format, type = type) ),
     stringsAsFactors = FALSE )
+  pr_str_df <- unique(pr_str_df)
 
   txt_data <- drop_useless_blank(txt_data)
   dat <- merge(txt_data, pr_str_df, by = "pr_id", all.x = TRUE, all.y = FALSE, sort = FALSE)
-  dat <- dat[order(dat$col_key, dat$id, dat$pos),]
-
-
+  dat <- dat[order(dat$col_key, dat$idrow, dat$pos),]
 
   dat$str <- run_fun[[type]](dat$format, dat$str, dat$str_is_run)
   dat$str <- hyperlink_fun[[type]](dat$href, dat$str)
 
-  group_ref_ <- group_ref(dat, c("id", "col_key"))
-  str_ <- tapply(dat$str, group_index(dat, c("id", "col_key")), paste, collapse = "")
+  group_ref_ <- group_ref(dat, c("idrow", "col_key"))
+  str_ <- tapply(dat$str, group_index(dat, c("idrow", "col_key")), paste, collapse = "")
   str_ <- data.frame(index_ = names(str_), str = as.character(str_), stringsAsFactors = FALSE )
   dat <- merge( group_ref_, str_, by = "index_", all.x = TRUE, all.y = TRUE, sort = FALSE)
   dat$index_ <- NULL
@@ -148,18 +151,18 @@ format.complex_tabpart <- function( x, type = "wml", header = FALSE, ... ){
   par_data <- x$styles$pars$get_map_format(type = type)
 
   tidy_content <- expand.grid(col_key = x$col_key,
-                              id = seq_len(nrow(x$dataset)),
+                              idrow = seq_len(nrow(x$dataset)),
                               stringsAsFactors = FALSE)
-  tidy_content <- merge(tidy_content, dat, by = c("col_key", "id"), all.x = TRUE, all.y = FALSE, sort = FALSE)
-  tidy_content <- merge(tidy_content, par_data, by = c("id", "col_key"), all.x = TRUE, all.y = FALSE, sort = FALSE)
+  tidy_content <- merge(tidy_content, dat, by = c("col_key", "idrow"), all.x = TRUE, all.y = FALSE, sort = FALSE)
+  tidy_content <- merge(tidy_content, par_data, by = c("idrow", "col_key"), all.x = TRUE, all.y = FALSE, sort = FALSE)
   tidy_content$str <- par_fun[[type]](tidy_content$format, tidy_content$str)
   tidy_content$format <- NULL
 
-  paragraphs <- as_wide_matrix_(as.data.frame(tidy_content[, c("col_key", "str", "id")]))
+  paragraphs <- as_wide_matrix_(as.data.frame(tidy_content[, c("col_key", "str", "idrow")]), idvar = "idrow")
 
   cell_data <- x$styles$cells$get_map_format(type = type)
   cell_data$col_key <- factor(cell_data$col_key, levels = x$col_keys)
-  cell_format <- as_wide_matrix_(as.data.frame(cell_data[, c("col_key", "format", "id")]))
+  cell_format <- as_wide_matrix_(as.data.frame(cell_data[, c("col_key", "format", "idrow")]), idvar = "idrow")
 
   cells <- cell_fun[[type]](str = paragraphs, format=cell_format,
                    span_rows = x$span$rows,
@@ -167,7 +170,7 @@ format.complex_tabpart <- function( x, type = "wml", header = FALSE, ... ){
 
   cells <- matrix(cells, ncol = length(x$col_keys), nrow = nrow(x$dataset) )
   cells <- apply(cells, 1, paste0, collapse = "")
-  rows <- row_fun[[type]](x$rowheights, cells, header)
+  rows <- row_fun[[type]](x$rowheights, cells, header, split = split)
   out <- paste0(rows, collapse = "")
 
   attr(out, "imgs") <- as.data.frame(img_data)
@@ -184,21 +187,25 @@ get_text_data <- function(x){
   txt_data <- mapply(function(x, f) f(x), x$dataset[x$col_keys], x$printers, SIMPLIFY = FALSE)
   txt_data <- do.call(cbind, txt_data)
   txt_data <- as.data.frame(txt_data, stringsAsFactors = FALSE )
-  txt_data$id <- seq_len(nrow(txt_data))
+
+  txt_data$idrow <- seq_len(nrow(txt_data))
   txt_data <- reshape(data = as.data.frame(txt_data, stringsAsFactors = FALSE),
-                      idvar = "id", new.row.names = NULL, timevar = "col_key",
+                      idvar = "idrow", new.row.names = NULL, timevar = "col_key",
                       times = x$col_keys,
                       varying = x$col_keys,
                       v.names = "str", direction = "long")
   row.names(txt_data) <- NULL
 
-  txt_data <- merge(mapped_data, txt_data, by = c("id", "col_key"),
+  txt_data <- merge(mapped_data, txt_data,
+                    by.x = c("idrow", "col_key"),
+                    by.y = c("idrow", "col_key"),
                     all.x = TRUE, all.y = FALSE, sort = FALSE )
   txt_data
 }
 
 #' @importFrom gdtools raster_write raster_str
-format.simple_tabpart <- function( x, type = "wml", header = FALSE, ... ){
+format.simple_tabpart <- function( x, type = "wml", header = FALSE,
+                                   split = FALSE, ... ){
   stopifnot(length(type) == 1)
   stopifnot( type %in% c("wml", "pml", "html") )
 
@@ -221,20 +228,21 @@ format.simple_tabpart <- function( x, type = "wml", header = FALSE, ... ){
   par_data <- x$styles$pars$get_map_format(type = type)
 
   tidy_content <- expand.grid(col_key = x$col_key,
-                              id = seq_len(nrow(x$dataset)),
+                              idrow = seq_len(nrow(x$dataset)),
                               stringsAsFactors = FALSE)
-  tidy_content <- merge(tidy_content, txt_data, by = c("col_key", "id"), all.x = TRUE, all.y = FALSE, sort = FALSE)
-  tidy_content <- merge(tidy_content, par_data, by = c("id", "col_key"),
+
+  tidy_content <- merge(tidy_content, txt_data, by = c("col_key", "idrow"), all.x = TRUE, all.y = FALSE, sort = FALSE)
+  tidy_content <- merge(tidy_content, par_data, by = c("idrow", "col_key"),
                         all.x = FALSE, all.y = FALSE, sort = FALSE)
   tidy_content$str <- par_fun[[type]](tidy_content$format, tidy_content$str)
   tidy_content$format <- NULL
 
   tidy_content$col_key <- factor(tidy_content$col_key, levels = x$col_keys)
-  paragraphs <- as_wide_matrix_(as.data.frame(tidy_content[, c("col_key", "str", "id")]))
+  paragraphs <- as_wide_matrix_(as.data.frame(tidy_content[, c("col_key", "str", "idrow")]), idvar = "idrow")
 
   cell_data <- x$styles$cells$get_map_format(type = type)
   cell_data$col_key <- factor(cell_data$col_key, levels = x$col_keys)
-  cell_format <- as_wide_matrix_(as.data.frame(cell_data[, c("col_key", "format", "id")]))
+  cell_format <- as_wide_matrix_(as.data.frame(cell_data[, c("col_key", "format", "idrow")]), idvar = "idrow")
 
   cells <- cell_fun[[type]](str = paragraphs, format=cell_format,
                             span_rows = x$span$rows,
@@ -242,7 +250,7 @@ format.simple_tabpart <- function( x, type = "wml", header = FALSE, ... ){
 
   cells <- matrix(cells, ncol = length(x$col_keys), nrow = nrow(x$dataset) )
   cells <- apply(cells, 1, paste0, collapse = "")
-  rows <- row_fun[[type]](x$rowheights, cells, header)
+  rows <- row_fun[[type]](x$rowheights, cells, header, split = split)
   out <- paste0(rows, collapse = "")
   out
 }
