@@ -242,10 +242,41 @@ xtable_to_flextable <- function(
 }
 
 
-formatC_with_na <- function(x, digits, format, na_string, ...){
+formatC_with_na <- function( x, na_string = "", ... ){
+  UseMethod("formatC_with_na")
+}
+
+formatC_with_na.default <- function( x, na_string = "", ... ){
+  ifelse( is.na(x), na_string, x )
+}
+
+formatC_with_na.character <- function( x, na_string = "", ... ){
+  ifelse( is.na(x), na_string, x )
+}
+
+formatC_with_na.factor <- function( x, na_string = "", ... ){
+  ifelse( is.na(x), na_string, as.character(x) )
+}
+
+formatC_with_na.logical <- function( x, na_string = "", true = "true", false = "false" ){
+  ifelse( is.na(x), na_string, ifelse(x, true, false) )
+}
+
+formatC_with_na.double <- function( x, na_string = "", digits, format = "d", ... ){
   ifelse( is.na(x), na_string, formatC(x, digits = digits, format = format, ...) )
 }
 
+formatC_with_na.integer <- function( x, na_string = "", digits, format, ... ){
+  ifelse( is.na(x), na_string, formatC(x, digits = digits, format = format, ...) )
+}
+
+formatC_with_na.Date <- function( x, na_string = "", fmt_date, ... ){
+  ifelse( is.na(x), na_string, format(x, fmt_date) )
+}
+
+formatC_with_na.POSIXt <- function( x, na_string = "", fmt_datetime, ... ){
+  ifelse( is.na(x), na_string, format(x, fmt_datetime) )
+}
 
 get_xtable_widths <- function(align, default_width = .3){
   rex <- "^(p\\{)([0-9\\.]+)(cm|in|px)(\\}$)"
